/**
 * @license
 * Copyright (c) 2019 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt The complete set of authors may be found
 * at http://polymer.github.io/AUTHORS.txt The complete set of contributors may
 * be found at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by
 * Google as part of the polymer project is also subject to an additional IP
 * rights grant found at http://polymer.github.io/PATENTS.txt
 */
import { Opts } from './flags';
import { CheckConfig } from './github';
import { Horizons } from './stats';
import { BenchmarkSpec } from './types';
/**
 * Validated and fully specified configuration.
 */
export interface Config {
    root: string;
    sampleSize: number;
    timeout: number;
    benchmarks: BenchmarkSpec[];
    horizons: Horizons;
    mode: 'automatic' | 'manual';
    jsonFile: string;
    legacyJsonFile: string;
    githubCheck?: CheckConfig;
    resolveBareModules: boolean;
    remoteAccessibleHost: string;
    forceCleanNpmInstall: boolean;
    csvFile: string;
}
export declare function makeConfig(opts: Opts): Promise<Config>;
export declare function applyDefaults(partial: Partial<Config>): Config;
/**
 * Derives the URL that we'll use to benchmark using the given HTML file or
 * directory on disk, relative to the root directory we'll be serving. Throws if
 * it's a file that doesn't exist, or a directory without an index.html.
 */
export declare function urlFromLocalPath(rootDir: string, diskPath: string): Promise<string>;
/** Parse horizon flags into signed horizon values. */
export declare function parseHorizons(strs: string[]): Horizons;
