/**
 * @license
 * Copyright (c) 2019 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt The complete set of authors may be found
 * at http://polymer.github.io/AUTHORS.txt The complete set of contributors may
 * be found at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by
 * Google as part of the polymer project is also subject to an additional IP
 * rights grant found at http://polymer.github.io/PATENTS.txt
 */
/**
 * Configuration data needed to create a GitHub Check.
 *
 * GitHub Checks are attached to a particular commit in a particular repo, and
 * are created by GitHub Apps, which are installed into an org or repo.
 *
 * More info at https://developer.github.com/v3/apps/
 *
 * Note that we do not currently manage a generally-accessible GitHub App. We
 * only support a fully self-service integration, whereby users are expected to
 * create their own GitHub App, install it to their repos, grant full power to
 * this binary to act as that App via a private key, and then piggyback on e.g.
 * Travis CI to actually run the benchmarks. This avoids the need to run any
 * services for the time being, but still lets us have our own standalone Check
 * tab in the GitHub UI.
 */
export interface CheckConfig {
    label: string;
    appId: number;
    installationId: number;
    repo: string;
    commit: string;
}
/**
 * Parse the --github-check flag.
 */
export declare function parseGithubCheckFlag(flag: string): CheckConfig;
/**
 * Create a pending GitHub check object and return a function that will mark
 * the check completed with the given markdown.
 */
export declare function createCheck(config: CheckConfig): Promise<(markdown: string) => void>;
